@@ -1,5 +1,5 @@
 import unittest
-from src.ocr_table import ocr_table
+from src.nkocr.ocr_table import ocr_table
 from PIL import Image
 
 
@@ -9,29 +9,29 @@ class TestTable(unittest.TestCase):
         self.assertTrue(True)
 
     def test_path_processing(self):
-        text = ocr_table("test/ocr.png")
+        text = ocr_table('test/ocr.png')
         type_output = isinstance(text.text, str)
         self.assertTrue(type_output)
 
     def test_url_processing(self):
-        text = ocr_table("https://img.icons8.com/all/500/general-ocr.png")
+        text = ocr_table('https://img.icons8.com/all/500/general-ocr.png')
         type_output = isinstance(text.text, str)
         self.assertTrue(type_output)
 
     def test_image_processing(self):
-        image = Image.open("test/ocr.png")
+        image = Image.open('test/ocr.png')
         text = ocr_table(image)
         type_output = isinstance(text.text, str)
         self.assertTrue(type_output)
 
     def test_execution_time(self):
-        text_and_time = ocr_table("test/ocr.png", show_performace=True)
+        text_and_time = ocr_table('test/ocr.png', show_performace=True)
         has_time = text_and_time.execution_time and \
             text_and_time.show_performace and \
             len(eval(repr(text_and_time))) > 1
         self.assertTrue(has_time)
 
     def test_wrong_type(self):
-        image = Image.open("test/ocr.png")
-        with self.assertRaises(TypeError) as error:
+        image = Image.open('test/ocr.png')
+        with self.assertRaises(TypeError):
             ocr_table(image, True)
